"use strict";
/* eslint-disable no-undefined, max-lines-per-function, no-magic-numbers */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var vitest_1 = require("vitest");
var actions_1 = __importDefault(require("./actions"));
var receivePage = actions_1.default.receivePage, requestPage = actions_1.default.requestPage, resetView = actions_1.default.resetView, changeView = actions_1.default.changeView;
var actionTypes_1 = require("./actionTypes");
(0, vitest_1.describe)("actions", function () {
    (0, vitest_1.test)("should create receive page action", function () {
        var action = receivePage({
            endpoint: "some/api/endpoint/",
            pageArgName: "p",
            idKey: "id",
            page: 2,
            token: "foo=bar",
            items: [
                "foo",
                "bar",
                "baz",
            ],
            total: 42,
        });
        (0, vitest_1.expect)(action).
            toEqual({
            type: actionTypes_1.RECEIVE_PAGE,
            meta: {
                endpoint: "some/api/endpoint/",
                pageArgName: "p",
                idKey: "id",
            },
            payload: {
                token: "foo=bar",
                page: 2,
                items: [
                    "foo",
                    "bar",
                    "baz",
                ],
                total: 42,
            },
        });
    });
    (0, vitest_1.test)("should create request page action", function () {
        var action = requestPage({
            endpoint: "some/api/endpoint/",
            resultsKey: "results",
            totalKey: "total",
            pageArgName: "p",
            idKey: "id",
            page: 2,
            token: "foo=bar",
        });
        (0, vitest_1.expect)(action).
            toEqual({
            type: actionTypes_1.REQUEST_PAGE,
            meta: {
                endpoint: "some/api/endpoint/",
                resultsKey: "results",
                totalKey: "total",
                pageArgName: "p",
                idKey: "id",
            },
            payload: {
                token: "foo=bar",
                page: 2,
            },
        });
    });
    (0, vitest_1.test)("should create reset view action", function () {
        var action = resetView("some/api/endpoint/", "name");
        (0, vitest_1.expect)(action).
            toEqual({
            type: actionTypes_1.RESET_VIEW,
            meta: {
                endpoint: "some/api/endpoint/",
            },
            payload: {
                token: "name",
            },
        });
    });
    (0, vitest_1.test)("should create change view action", function () {
        var action = changeView("some/api/endpoint/", {
            token: "name",
            view: 2,
        });
        (0, vitest_1.expect)(action).
            toEqual({
            type: actionTypes_1.CHANGE_VIEW,
            meta: {
                endpoint: "some/api/endpoint/",
            },
            payload: {
                view: 2,
                token: "name",
            },
        });
    });
});
//# sourceMappingURL=actions.test.js.map